@@ -47,6 +47,7 @@ from ....models.cv.diffusion.utils import CONCAT_KEY
 from ....models.cv.diffusion.utils import CONCAT_TYPE
 from ....models.cv.diffusion.utils import HYBRID_TYPE
 from ....models.cv.diffusion.utils import CROSS_ATTN_KEY
+from ....models.cv.diffusion.utils import CONTROL_HINT_KEY
 from ....models.cv.diffusion.cond_models import CLIPTextConditionModel
 from ....models.cv.diffusion.samplers.ddim import DDIMMixin
 from ....models.cv.diffusion.samplers.solver import DPMSolver
@@ -228,13 +229,16 @@ class DiffusionAPI(APIMixin):
         cond: Optional[Any] = None,
         cond_concat: Optional[Tensor] = None,
         unconditional_cond: Optional[Any] = None,
+        hint: Optional[Tensor] = None,
         num_steps: Optional[int] = None,
         clip_output: bool = True,
         callback: Optional[Callable[[Tensor], Tensor]] = None,
-        batch_size: int = 1,
+        batch_size: Optional[int] = None,
         verbose: bool = True,
         **kwargs: Any,
     ) -> Tensor:
+        if batch_size is None:
+            batch_size = num_samples
         registered_custom = False
         if self.cond_model is not None:
             clip_skip = kwargs.get(
@@ -292,10 +296,18 @@ class DiffusionAPI(APIMixin):
             self.sampler.unconditional_cond = uncond.clone()
         with eval_context(self.m):
             with self.amp_context:
-                for batch in iterator:
+                for i, batch in enumerate(iterator):
+                    # from the 2nd batch forward, we need to re-generate new seeds
+                    if i >= 1:
+                        seed = new_seed()
                     i_kw = shallow_copy_dict(kw)
                     i_cond = batch[INPUT_KEY].to(self.device)
-                    repeat = lambda t: t.repeat_interleave(len(i_cond), dim=0)
+                    i_n = len(i_cond)
+                    repeat = (
+                        lambda t: t
+                        if t.shape[0] == i_n
+                        else t.repeat_interleave(i_n, dim=0)
+                    )
                     if z is not None:
                         i_z = repeat(z)
                     else:
@@ -304,7 +316,7 @@ class DiffusionAPI(APIMixin):
                             in_channels -= cond.shape[1]
                         elif cond_concat is not None:
                             in_channels -= cond_concat.shape[1]
-                        i_z_shape = len(i_cond), in_channels, *size[::-1]
+                        i_z_shape = i_n, in_channels, *size[::-1]
                         i_z, _ = self._set_seed_and_variations(
                             seed,
                             lambda: torch.randn(i_z_shape, device=self.device),
@@ -326,7 +338,7 @@ class DiffusionAPI(APIMixin):
                             dx = max(-dx, 0)
                             dy = max(-dy, 0)
                             i_opt_z_shape = (
-                                len(i_cond),
+                                i_n,
                                 self.m.in_channels,
                                 *z_opt_shape,
                             )
@@ -365,6 +377,14 @@ class DiffusionAPI(APIMixin):
                             CROSS_ATTN_KEY: i_cond,
                             CONCAT_KEY: cond_concat,
                         }
+                    if hint is not None:
+                        if isinstance(i_cond, dict):
+                            i_cond[CONTROL_HINT_KEY] = hint
+                        else:
+                            i_cond = {
+                                CROSS_ATTN_KEY: i_cond,
+                                CONTROL_HINT_KEY: hint,
+                            }
                     with switch_sampler_context(self, i_kw.get("sampler")):
                         i_sampled = self.m.decode(i_z, cond=i_cond, **i_kw)
                     sampled.append(i_sampled.cpu().float())
@@ -486,7 +506,7 @@ class DiffusionAPI(APIMixin):
         num_steps: Optional[int] = None,
         clip_output: bool = True,
         callback: Optional[Callable[[Tensor], Tensor]] = None,
-        batch_size: int = 1,
+        batch_size: Optional[int] = None,
         verbose: bool = True,
         **kwargs: Any,
     ) -> Tensor:
@@ -1053,7 +1073,7 @@ class DiffusionAPI(APIMixin):
         with switch_sampler_context(self, kwargs.get("sampler")):
             z, noise, kwargs = self._q_sample(z, num_steps, **kwargs)
             return self.sample(
-                1,
+                z.shape[0],
                 export_path,
                 z=z,
                 z_ref=z_ref,
